#!/usr/bin/env python3
"""Test the list of possible stages in an object."""

import sys
import json
from pathlib import Path
cwd = Path(__file__).parent.parent
sys.path.insert(0, cwd.as_posix())

from itkdb_gtk import ITkDBlogin, ITkDButils


def set_stages(session, SN):
    """Prepare the stages combo."""
    # Check the object stage
    print("+++ {}".format(SN))
    try:
        obj = ITkDButils.get_DB_component(session, SN)

        with open("object-{}.json".format(SN), "w", encoding="utf-8") as ofile:
            ofile.write(json.dumps(obj, indent=4))

        currentStage = obj["currentStage"]["code"]
        print("Current Stage: {}".format(currentStage))

        for stg in obj["stages"]:
            S = stg["code"]
            print("- {}".format(S))

    except Exception as E:
        print("Something went wrong with the stages\n{}".format(E))


def main():
    """Entry point."""
    dlg = ITkDBlogin.ITkDBlogin()
    client = dlg.get_client()
    if client is None:
        print("Could not connect to DB with provided credentials.")
        dlg.die()
        sys.exit()

    set_stages(client, "IFIC-R5-0046")
    set_stages(client, "20USEM50000110")
    
    set_stages(client, "IFIC-R0-0056")
    set_stages(client, "20USEM00000198")
    
    dlg.die()


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
"""GUI to upload tests."""
import argparse
import json
import sys
import io
import platform
import tempfile
import datetime
from pathlib import Path

try:
    import itkdb_gtk

except ImportError:
    cwd = Path(__file__).parent.parent
    sys.path.append(cwd.as_posix())

from itkdb_gtk import dbGtkUtils, ITkDBlogin, ITkDButils, QRScanner, findVTRx

import gi
gi.require_version("Gtk", "3.0")
from gi.repository import Gtk, GLib


_XX_STRIPS = ['SB', 'SE', 'SG', 'CE']
def check_serial_number(serial_number):
    """Checks for validity of Serial Numbers.

        See itkdb/identifiers.py
    """
    if len(serial_number) != 14:
        return False

    if serial_number[0:3] != '20U':
        return False

    XX = serial_number[3:5]
    if XX not in _XX_STRIPS:
        return False

    return True


class FindComponent(dbGtkUtils.ITkDBWindow):
    """Read QR of bar code and retrieve information about component."""

    def __init__(self, session, help_link=None):
        """Initialization.

        Args:
            session: ITkDB session
            help_link: link to help page.

        """
        super().__init__(session=session, title="Find Component", help_link=help_link)
        self.scanner = QRScanner.QRScanner(self.get_qrcode)
        self.ofd = None  # Output file descriptor
        self.header = "SN,AltID,Type,Location,StageCode\n"
        self.file_path = ""
        self.inner_buffer = io.StringIO()
        self.inner_buffer.write(self.header)
        self.init_window()

    def delete(self, *args):
        """Destructor."""
        if self.ofd is not None:
            self.ofd.close()

        tmp_dir = Path("/tmp" if platform.system() == "Darwin" else tempfile.gettempdir())
        dt = datetime.datetime.now()
        dts =  "{:02d}{:02d}{:02d}_{:02d}{:02d}{:02d}".format(dt.day, dt.month, dt.year, dt.hour, dt.minute, dt.second)
        ofnam = tmp_dir / "scanned_objects_{}.csv".format(dts)
        with open(ofnam, "w", encoding="utf-8") as ofile:
            ofile.write(self.inner_buffer.getvalue())
            ofile.close()

    def init_window(self):
        """Create the Gtk window."""
        # Initial tweaks
        self.connect("destroy", self.delete)
        self.set_border_width(10)

        # Prepare HeaderBar
        self.hb.props.title = "Find Component"


        # File name
        box = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL, spacing=6)
        self.mainBox.pack_start(box, False, False, 0)
        self.open_btn = Gtk.Button(label="Start Recording")
        self.open_btn.set_tooltip_text("Click to start saving information of the DB objects in a local CSV file. Select output file.")
        self.open_btn.connect("clicked", self.on_file_set)
        box.pack_start(self.open_btn, False, False, 0)

        self.close_btn = Gtk.Button(label="Stop Recording")
        self.close_btn.set_sensitive(False)
        self.close_btn.set_tooltip_text("Stop recording information about the DB objects.")
        self.close_btn.connect("clicked", self.on_file_close)
        box.pack_start(self.close_btn, False, False, 0)


        self.file_name = Gtk.Label(label="No output file selected")
        self.mainBox.pack_start(self.file_name, False, False, 5)

        self.scanner_dev = Gtk.Label(label="No scanner found")
        self.mainBox.pack_start(self.scanner_dev, False, False, 5)

        # Object Data
        lbl = Gtk.Label(label="Scan your QR or bar code. Information will appear below.")
        self.mainBox.pack_start(lbl, False, False, 10)


        #btn = Gtk.Button(label="Test Button")
        #btn.connect("clicked", self.test_qrcode)
        #self.mainBox.pack_start(btn, True, True, 0)

        # The text view
        self.mainBox.pack_start(self.message_panel.frame, True, True, 0)

        self.timer_id = GLib.timeout_add(500, self.find_scanner)

        self.show_all()

    def find_scanner(self, *args):
        """Figure out if there is a scanner connected."""
        if self.scanner.reader is None:
            self.scanner_dev.set_text("Rading from keyboard or scanner in HID mode")
        else:
            self.scanner_dev.set_text("Found scanner in {}".format(self.scanner.reader.name))

        return True

    def on_file_set(self, *args):
        """File selected.

            Opens the file for writing the information aobut the components
            scanned.
        """
        fc = Gtk.FileChooserDialog(title="Save data file", action=Gtk.FileChooserAction.SAVE)
        fc.set_current_name("scanned_components.csv")
        fc.add_buttons(
            Gtk.STOCK_CANCEL,
            Gtk.ResponseType.CANCEL,
            Gtk.STOCK_OPEN,
            Gtk.ResponseType.OK,
        )
        response = fc.run()
        if response != Gtk.ResponseType.OK:
            fc.destroy()
            return

        filename = fc.get_filename()

        if Path(filename).exists():
            overwrite = dbGtkUtils.ask_for_confirmation("File already exists. Overwrite?", "{}".format(filename))
            if not overwrite:
                fc.destroy()
                return

        fc.destroy()
        self.close_btn.set_sensitive(True)
        self.open_btn.set_sensitive(False)
        self.file_name.set_text("Output File: {}".format(filename))
        self.file_path = filename
        self.ofd = open(filename, "w", encoding="utf-8")
        self.ofd.write(self.header)
        self.ofd.flush()

    def on_file_close(self, *args):
        """File closed."""
        if self.ofd is not None:
            self.write_message("File {} closed.".format(self.file_path))
            self.file_path = ""
            self.ofd.close()
            self.ofd = None
            self.close_btn.set_sensitive(False)
            self.open_btn.set_sensitive(True)
            self.file_name.set_text("No output file selected")

    def write_csv_line(self, obj):
        """Write a line in the output file if opened."""
        msg = "{}, {}, {}, {}, {}\n".format(
                obj["serialNumber"],
                obj["alternativeIdentifier"],
                obj["componentType"]["name"],
                obj["currentLocation"]["code"],
                obj["currentStage"]["code"])
        self.inner_buffer.write(msg)
        if self.ofd is not None:
            self.ofd.write(msg)
            self.ofd.flush()


    def get_qrcode(self, txt):
        """Gets data from QR scanner."""
        is_vtrx = False
        SN = None
        obj = None
        if findVTRx.is_vtrx(txt):
            is_vtrx = True
            try:
                SN = findVTRx.find_vtrx(self.session, txt)

            except ValueError as e:
                self.write_message("Error: {}\n".format(e))
                return
        else:
            SN = txt

        if SN:
            obj = ITkDButils.get_DB_component(self.session, SN)

        if obj is None:
            self.write_message("Object {} not found in DB\n\n".format(SN))
            if is_vtrx or check_serial_number(SN):
                obj = {
                    "serialNumber": "",
                    "alternativeIdentifier": txt if is_vtrx else SN,
                    "componentType": "",
                    "currentLocation": {"code": ""},
                    "currentStage": {"code": "ORPHAN"},
                }
                self.write_csv_line(obj)

            return

        if is_vtrx and obj["alternativeIdentifier"] is None:
            obj["alternativeIdentifier"] = txt

        msg = "\n{}\nObject SN: {}\nObject Alt. ID: {}\nObject Type: {}\nObject Loc. {}\nObject stage: {} - {}\n\n".format(
            txt,
            obj["serialNumber"],
            obj["alternativeIdentifier"],
            obj["componentType"]["name"],
            obj["currentLocation"]["name"],
            obj["currentStage"]["code"],
            obj["currentStage"]["name"])
        self.write_message(msg)

        # SAve if there is an open file.
        self.write_csv_line(obj)

    def test_qrcode(self, *args):
        """Gets data from QR scanner."""
        txt = "a3c671bf38d3957dc053c6e5471aa27e"
        self.write_message("{}\n".format(txt))

        if findVTRx.is_vtrx(txt):
            try:
                SN = findVTRx.find_vtrx(self.session, txt)
            except ValueError as e:
                self.write_message("Error: {}\n".format(e))
                return
        else:
            SN = txt

        obj = ITkDButils.get_DB_component(self.session, SN)
        if obj is None:
            self.write_message("Object {} not found in DB\n\n".format(SN))
            return


        msg = "\n\nObject SN: {}\nObject Alt. ID: {}\nObject Type: {}\nObject Loc.: {}\nObject stage: {} - {}\n".format(
            obj["serialNumber"],
            obj["alternativeIdentifier"],
            obj["componentType"]["name"],
            obj["currentLocation"]["name"],
            obj["currentStage"]["code"],
            obj["currentStage"]["name"])

        self.write_message(msg)
        self.write_message("")

def main():
    """Main entry."""
    HELP_LINK="https://itkdb-gtk.docs.cern.ch/findComponent.html"

    # DB login
    dlg = ITkDBlogin.ITkDBlogin()
    client = dlg.get_client()
    if client is None:
        print("Could not connect to DB with provided credentials.")
        dlg.die()
        sys.exit()

    client.user_gui = dlg

    window = FindComponent(client, help_link=HELP_LINK)
    window.set_accept_focus(True)
    window.present()
    window.connect("destroy", Gtk.main_quit)

    try:
        Gtk.main()

    except KeyboardInterrupt:
        print("Arrrgggg!!!")

    dlg.die()

if __name__ == "__main__":
    main()



#!/usr/bin/env python3
"""Test dashboard."""
import sys


from pathlib import Path
cwd = Path(__file__).parent.parent
sys.path.insert(0, cwd.as_posix())

#try:
#    import itkdb_gtk
#
#except ImportError:
#    from pathlib import Path
#    cwd = Path(__file__).parent.parent
#    sys.path.append(cwd.as_posix())


from itkdb_gtk import dbGtkUtils
from itkdb_gtk import GetShipments
from itkdb_gtk import ITkDBlogin
from itkdb_gtk import CreateShipments
from itkdb_gtk import UploadTest
from itkdb_gtk import UploadMultipleTests
from itkdb_gtk import GlueWeight
from itkdb_gtk import UploadModuleIV
from itkdb_gtk import WireBondGui
from itkdb_gtk import PanelVisualInspection
from itkdb_gtk import VisualInspection
from itkdb_gtk import findComponent


HAS_PETALQC=False
try:
    from petal_qc.metrology.coreMetrology import CoreMetrology, CoreMetrologyOptions
    from petal_qc.thermal.coreThermal import CoreThermal
    from petal_qc.thermal.IRPetalParam import IRPetalParam
    from petal_qc.metrology.uploadPetalInformation import AVSPanel, AVSOptions
    from petal_qc import PetalReceptionTests

    HAS_PETALQC = True
except ImportError as E:
    HAS_PETALQC = False


import gi

gi.require_version("Gtk", "3.0")
from gi.repository import Gtk

HELP_LINK="https://itkdb-gtk.docs.cern.ch"

class DashWindow(dbGtkUtils.ITkDBWindow):
    """Dashboard class."""
    UPLOAD_TEST = 1
    UPLOAD_MANY_TESTS = 2
    CREATE_SHIPMNT = 3
    RECV_SHIPMNT = 4
    PETAL_RECEPTION = 5
    GLUE_WEIGHT = 6
    MOD_IV = 7
    WIRE_BOND = 8
    PANEL_VI = 9
    MODULE_VI = 10
    PETAL_CORE_METRO = 11
    PETAL_CORE_THERMAL = 12
    PETAL_INFORMATION = 13
    FIND_COMPONENT = 14

    def __init__(self, session):
        """Initialization."""
        super().__init__(title="ITkDB Dashboard", session=session, help_link=HELP_LINK)
        self.mask = 0

        self.program = "ITkDB Dash Board"
        self.info_comment = "Dash board to launch different ITkDB commands."

        # set border width
        self.set_border_width(10)

        # Prepare dashboard
        #lbl = Gtk.Label()
        #lbl.set_markup("<big><b>ITkDB available commands.</b></big>")
        #self.mainBox.pack_start(lbl, True, True, 0)

        grid = Gtk.Grid(column_spacing=5, row_spacing=5)
        self.mainBox.pack_start(grid, False, True, 5)

        irow = 0
        lbl = Gtk.Label()
        lbl.set_markup("<b>Tests</b>")
        lbl.set_xalign(0)
        grid.attach(lbl, 0, irow, 1, 1)

        irow += 1
        btnTest = Gtk.Button(label="Upload Single Test")
        btnTest.connect("clicked", self.upload_test)
        grid.attach(btnTest, 0, irow, 1, 1)

        btnTest = Gtk.Button(label="Upload Multiple Tests")
        btnTest.connect("clicked", self.upload_multiple_tests)
        grid.attach(btnTest, 1, irow, 1, 1)

        irow +=1
        separator = Gtk.Separator(orientation=Gtk.Orientation.HORIZONTAL)
        grid.attach(separator, 0, irow, 2, 1)

        irow += 1
        btnModVI = Gtk.Button(label="Module/Sensor Visual Insp.")
        btnModVI.connect("clicked", self.module_VI)
        grid.attach(btnModVI, 0, irow, 1, 1)
        

        btnPanelVI = Gtk.Button(label="Panel Visual Insp.")
        btnPanelVI.connect("clicked", self.panel_VI)
        grid.attach(btnPanelVI, 1, irow, 1, 1)
        
        irow += 1
        btnModIV = Gtk.Button(label="Sensor/Module IV")
        btnModIV.connect("clicked", self.module_IV)
        grid.attach(btnModIV, 0, irow, 1, 1)

        btnWireBond = Gtk.Button(label="Wire Bond")
        btnWireBond.connect("clicked", self.wire_bond)
        grid.attach(btnWireBond, 1, irow, 1, 1)

        irow += 1
        btnWeight = Gtk.Button(label="GlueWeight")
        btnWeight.connect("clicked", self.glue_weight)
        grid.attach(btnWeight, 0, irow, 1, 1)



        if HAS_PETALQC:
            irow +=1
            separator = Gtk.Separator(orientation=Gtk.Orientation.HORIZONTAL)
            grid.attach(separator, 0, irow, 2, 1)

            irow +=1
            btnPetalInfo = Gtk.Button(label="AVS Petal Info")
            btnPetalInfo.connect("clicked", self.upload_petal_info)
            grid.attach(btnPetalInfo, 0, irow, 1, 1)

            btnGnd = Gtk.Button(label="Petal Reception")
            btnGnd.connect("clicked", self.petal_reception)
            grid.attach(btnGnd, 1, irow, 1, 1)

            irow +=1
            btnPetalMetrology = Gtk.Button(label="Petal Core Metrology")
            btnPetalMetrology.connect("clicked", self.petal_metrology)
            grid.attach(btnPetalMetrology, 0, irow, 1, 1)

            btnPetalThermal = Gtk.Button(label="Petal Core Thermal")
            btnPetalThermal.connect("clicked", self.petal_thermal)
            grid.attach(btnPetalThermal, 1, irow, 1, 1)

        irow += 1
        grid.attach(Gtk.Label(), 0, irow, 1, 1)

        irow += 1
        lbl = Gtk.Label()
        lbl.set_markup("<b>Shipments</b>")
        lbl.set_xalign(0)
        grid.attach(lbl, 0, irow, 1, 1)

        irow += 1
        sendS = Gtk.Button(label="Create Shipment")
        sendS.connect("clicked", self.create_shipment)
        grid.attach(sendS, 0, irow, 1, 1)

        recS = Gtk.Button(label="Receive Shipment")
        recS.connect("clicked", self.receive_shipment)
        grid.attach(recS, 1, irow, 1, 1,)

        irow += 1
        lbl = Gtk.Label()
        lbl.set_markup("<b>Utils</b>")
        lbl.set_xalign(0)
        grid.attach(lbl, 0, irow, 1, 1)

        irow += 1
        findC = Gtk.Button(label="Find Component")
        findC.connect("clicked", self.find_component)
        findC.set_tooltip_text("Scan your QR or bar code and get info from DB.")
        grid.attach(findC, 0, irow, 1, 1,)


        self.mainBox.pack_start(Gtk.Separator(orientation=Gtk.Orientation.HORIZONTAL), False, True, 5)

        self.show_all()

    def upload_test(self, *args):
        """Launch upload test."""
        bitn = DashWindow.UPLOAD_TEST
        bt = 1 << bitn
        if self.mask & bt:
            return

        self.mask |= bt
        W = UploadTest.UploadTest(
            self.session,
            help_link="{}/uploadSingleTest.html".format(HELP_LINK)
        )
        W.connect("destroy", self.app_closed, bitn)

    def upload_multiple_tests(self, *args):
        """Launch upload multiple test."""
        bitn = DashWindow.UPLOAD_MANY_TESTS
        bt = 1 << bitn
        if self.mask & bt:
            return

        self.mask |= bt
        W = UploadMultipleTests.UploadMultipleTests(
            self.session,
            help_link="{}/uploadMultipleTests.html".format(HELP_LINK)
        )
        W.connect("destroy", self.app_closed, bitn)

    def create_shipment(self, *args):
        """Launch createShipment."""
        bitn = DashWindow.CREATE_SHIPMNT
        bt = 1 << bitn
        if self.mask & bt:
            return

        self.mask |= bt
        W = CreateShipments.CreateShipments(
            self.session,
            help_link="{}/createShipment.html".format(HELP_LINK)
        )
        W.connect("destroy", self.app_closed, bitn)

    def receive_shipment(self, *args):
        """Launch getShipments."""
        bitn = DashWindow.RECV_SHIPMNT
        bt = 1 << bitn
        if self.mask & bt:
            return

        self.mask |= bt
        W = GetShipments.ReceiveShipments(
            self.session,
            help_link="{}/receiveShipments.html".format(HELP_LINK)
        )
        W.connect("destroy", self.app_closed, bitn)


    def glue_weight(self, *args):
        """Glue Weight test."""
        bitn = DashWindow.GLUE_WEIGHT
        bt = 1 << bitn
        if self.mask & bt:
            return

        self.mask |= bt
        W = GlueWeight.GlueWeight(self.session, help_link=HELP_LINK)
        W.connect("destroy", self.app_closed, bitn)

    def module_IV(self, *args):
        """Module IV tests."""
        bitn = DashWindow.MOD_IV
        bt = 1 << bitn
        if self.mask & bt:
            return

        self.mask |= bt
        W = UploadModuleIV.IVwindow(
            self.session,
            help_link="{}/uploadModuleIV.html".format(HELP_LINK)
        )
        W.connect("destroy", self.app_closed, bitn)

    def wire_bond(self, *args):
        """Module IV tests."""
        bitn = DashWindow.WIRE_BOND
        bt = 1 << bitn
        if self.mask & bt:
            return

        self.mask |= bt
        W = WireBondGui.WireBond(
            session=self.session,
            title="Wirebond",
            help_link="{}//wirebondTest.html".format(HELP_LINK),
        )
        W.connect("destroy", self.app_closed, bitn)
        W.show_all()

    def panel_VI(self, *args):
        """Panel VI tests."""
        bitn = DashWindow.PANEL_VI
        bt = 1 << bitn
        if self.mask & bt:
            return

        self.mask |= bt
        W = PanelVisualInspection.PanelVisualInspection(
            session=self.session,
            title="Panel Visual Inspection",
            help_link="{}/panelVisualInspection.html".format(HELP_LINK),
        )
        W.connect("destroy", self.app_closed, bitn)
        W.show_all()

    def module_VI(self, *args):
        """Panel VI tests."""
        bitn = DashWindow.MODULE_VI
        bt = 1 << bitn
        if self.mask & bt:
            return

        self.mask |= bt
        W = VisualInspection.ModuleVisualInspection(
            session=self.session,
            title="Module/Sensor Visual Inspection",
            help_link="{}/moduleVisualInspection.html".format(HELP_LINK),
        )
        W.connect("destroy", self.app_closed, bitn)
        W.show_all()
        
        
    def find_component(self, *args):
        """Find Component."""
        bitn = DashWindow.FIND_COMPONENT
        bt = 1 << bitn
        if self.mask & bt:
            return

        W = findComponent.FindComponent(
            self.session,
            help_link="{}/findComponent.html".format(HELP_LINK)
            )
        
        W.connect("destroy", self.app_closed, bitn)
        
    def petal_reception(self, *args):
        """Petal GND/VI test."""
        bitn = DashWindow.PETAL_RECEPTION
        bt = 1 << bitn
        if self.mask & bt:
            return

        self.mask |= bt
        W = PetalReceptionTests.PetalReceptionTests(
            self.session,
            help_link="{}/petalReceptionTests.html".format(HELP_LINK)
        )
        W.connect("destroy", self.app_closed, bitn)


    def upload_petal_info(self, *srgs):
        """Upload petal Info."""
        if not HAS_PETALQC:
            return

        bitn = DashWindow.PETAL_INFORMATION
        bt = 1 << bitn
        if self.mask & bt:
            return

        self.mask |= bt
        W = AVSPanel(self.session, AVSOptions())
        W.connect("destroy", self.app_closed, bitn)
        W.show_all()

    def petal_metrology(self, *args):
        """Do petal metrology"""
        if not HAS_PETALQC:
            return

        bitn = DashWindow.PETAL_CORE_METRO
        bt = 1 << bitn
        if self.mask & bt:
            return

        self.mask |= bt
        opts = CoreMetrologyOptions()
        W = CoreMetrology(opts, session=self.session, title="Petal Core Metrology")
        W.connect("destroy", self.app_closed, bitn)
        W.show_all()

    def petal_thermal(self, *args):
        """Do petal thermal."""
        if not HAS_PETALQC:
            return

        bitn = DashWindow.PETAL_CORE_THERMAL
        bt = 1 << bitn
        if self.mask & bt:
            return

        self.mask |= bt
        opt = IRPetalParam()
        opt.files = []
        opt.golden = None
        opt.folder = None
        opt.out = None
        opt.alias = None
        opt.SN = None
        opt.desy = False
        W = CoreThermal(opt, self.session, title="Petal Thermal Test.")
        W.connect("destroy", self.app_closed, bitn)
        W.show_all()

    def app_closed(self, *args):
        """Application window closed. Clear mask."""
        bt = 1 << args[1]
        self.mask &= ~bt
        # print(bt, self.mask)


def main():
    """main entry."""
    # DB login
    dlg = ITkDBlogin.ITkDBlogin()
    client = dlg.get_client()
    if client is None:
        print("Could not connect to DB with provided credentials.")
        dlg.die()
        sys.exit()

    client.user_gui = dlg

    dashW = DashWindow(client)
    dashW.connect("destroy", Gtk.main_quit)
    try:
        Gtk.main()

    except KeyboardInterrupt:
        print("Arrrgggg!!!")

    dlg.die()


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
"""Test Batches."""

try:
    import itkdb_gtk
    
except ImportError:
    import sys
    from pathlib import Path
    cwd = Path(__file__).parent.parent
    sys.path.append(cwd.as_posix())

from itkdb_gtk import ITkDBlogin, ITkDButils


def get_all_Petals(session):
    """Find all petal cores"""
    # find all cores
    # Now all the objects
    payload = {
        "filterMap": {
            #"componentType": ["BT"],
            "componentType": ["CORE_PETAL"],
            "type": ["CORE_AVS"],
            #"currentLocation": ["IFIC"],
        },
        "sorterList": [
            {"key": "alternativeIdentifier", "descending": False }
        ],
    }
    core_list = session.get("listComponents", json=payload)
    return core_list

def list_petal_core_batches(session):
    """Get list of Petal core batches"""
    payload = {
        "filterMap": {
            "project": "S",
            "batchType": ["PETAL_CORE_BATCH_TYPE"],
        }
    }
    batch_list = session.get("listBatches", json=payload)
    rc = {}
    for B in batch_list:
        rc[B["number"] ]= B["id"]

    return rc


def create_petal_core_batchType(session):
    """Creates the batches."""
    out = session.post(
        "createBatchType",
        json={
            "code": "PETAL_CORE_BATCH_TYPE",
            "name": "Petal Core",
            "state": "active",
            "project": "S",
        },
    )
    out = session.post(
        "createBatch",
        json={
            "project": "S",
            "batchType": "PETAL_CORE_BATCH_TYPE",
            "number": "PETAL_CORE_PROTO",
            "ownerInstituteList": ["IFIC", "AVS", "DESYHH"],
        },
    )
    out = session.post(
        "createBatch",
        json={
            "project": "S",
            "batchType": "PETAL_CORE_BATCH_TYPE",
            "number": "PETAL_CORE_PREPROD",
            "ownerInstituteList": ["IFIC", "AVS", "DESYHH"],
        },
    )
    out = session.post(
        "createBatch",
        json={
            "project": "S",
            "batchType": "PETAL_CORE_BATCH_TYPE",
            "number": "PETAL_CORE_PROD",
            "ownerInstituteList": ["IFIC", "AVS", "DESYHH"],
        },
    )


def main(session):
    """Create batchers."""
    #create_petal_core_batchType(session)
    
    batch_list = list_petal_core_batches(session)
    
#    # create the batches
#    for bc, bid in batch_list.items():
#        payload = {
#            "project": "S",
#            "batchType": bc,
#            "number": "1",
#            "ownerInstituteList": ["AVS", "IFIC", "DESYHH"]
#        }
#        rc = session.post("createBatch", json=payload)
        
    
    for petal_core in get_all_Petals(session):
        aliasID = petal_core["alternativeIdentifier"]
        if "PPB" in aliasID:
            batch_code = "PETAL_CORE_PREPROD"
        elif "PPC" in aliasID:
            batch_code = "PETAL_CORE_PROD"
        elif "test" in aliasID.lower():
            continue
        else:
            batch_code = "PETAL_CORE_PROTO"
        
        print("{} - {}".format(aliasID, batch_code))
        rc = session.post("addBatchComponent", json={"id":batch_list[batch_code], "component": petal_core["id"]})
        if rc is None:
            pass
        else:
            pass


if __name__ == "__main__":
    # ITk_PB authentication
    dlg = ITkDBlogin.ITkDBlogin()
    db_session = dlg.get_client()

    try:
        main(db_session)

    except Exception as E:
        print(E)
        
    dlg.die()



#!/usr/bin/env python3
"""Tells which VTRx correspods to the package serial number scanned."""

import re

__valid_sn__ = re.compile("J-(SD|MT)[0-9]+")

def is_vtrx(SN):
    """Checks if the SN corresponds to a VTRx."""
    if __valid_sn__.match(SN) is None:
        return False
    return True

def find_vtrx(client, SN):
    """Searches VTRx."""
    if not is_vtrx(SN):
        return None

    payload = {
        "filterMap": {
            "project": "CE",
            "componentType": ["VTRX"],
            "propertyFilter": [{"code": "PACKAGE_SN", "operator": "=", "value": SN}],
        }
    }
    out = client.get("listComponentsByProperty", json=payload)
    vtrx = None
    nitem = 0
    for item in out:
        vtrx = item["serialNumber"]
        nitem += 1

    if nitem > 1:
        raise ValueError("Too many VTRx with same device SN.")

    return vtrx

if __name__ == "__main__":
    import sys
    from itkdb_gtk import ITkDBlogin, ITkDButils
    # DB login
    dlg = ITkDBlogin.ITkDBlogin()
    client = dlg.get_client()
    if client is None:
        print("Could not connect to DB with provided credentials.")
        dlg.die()
        sys.exit()

    SN = find_vtrx(client, "J-SD55496290")
    if SN is not None:
        obj = ITkDButils.get_DB_component(client, SN)
        if obj is None:
            print("Object {} not found in DB\n\n".format(SN))

        else:
            msg = "\n\nObject SN: {}\nObject Alt. ID: {}\nObject Type: {}\nObject Loc.: {}\nObject stage: {} - {}\n".format(
                obj["serialNumber"],
                obj["alternativeIdentifier"],
                obj["componentType"]["name"],
                obj["currentLocation"]["name"],
                obj["currentStage"]["code"],
                obj["currentStage"]["name"])
            print(msg)

    dlg.die()
